@@ -35,22 +35,30 @@
 (defvar company-keywords-alist
   ;; Please contribute corrections or additions.
   `((c++-mode
-     "alignas" "alignof" "asm" "auto" "bool" "break" "case" "catch" "char"
-     "char16_t" "char32_t" "class" "const" "const_cast" "constexpr" "continue"
-     "decltype" "default" "delete" "do" "double" "dynamic_cast" "else" "enum"
-     "explicit" "export" "extern" "false" "final" "float" "for" "friend"
-     "goto" "if" "inline" "int" "long" "mutable" "namespace" "new" "noexcept"
-     "nullptr" "operator" "override"
-     "private" "protected" "public" "register" "reinterpret_cast"
-     "return" "short" "signed" "sizeof" "static" "static_assert"
-     "static_cast" "struct" "switch" "template" "this" "thread_local"
-     "throw" "true" "try" "typedef" "typeid" "typename"
-     "union" "unsigned" "using" "virtual" "void" "volatile" "wchar_t" "while")
+     ;; from https://en.cppreference.com/w/cpp/keyword
+     "alignas" "alignof" "and" "and_eq" "asm" "atomic_cancel" "atomic_commit"
+     "atomic_noexcept" "auto" "bitand" "bitor" "bool" "break" "case" "catch"
+     "char" "char16_t" "char32_t" "char8_t" "class" "co_await" "co_return"
+     "co_yield" "compl" "concept" "const" "const_cast" "consteval" "constexpr"
+     "constinit" "continue" "decltype" "default" "delete" "do" "double"
+     "dynamic_cast" "else" "enum" "explicit" "export" "extern" "false" "final"
+     "float" "for" "friend" "goto" "if" "import" "inline" "int" "long" "module"
+     "mutable" "namespace" "new" "noexcept" "not" "not_eq" "nullptr" "operator"
+     "or" "or_eq" "override" "private" "protected" "public" "reflexpr" "register"
+     "reinterpret_cast" "requires" "return" "short" "signed" "sizeof" "static"
+     "static_assert" "static_cast" "struct" "switch" "synchronized" "template"
+     "this" "thread_local" "throw" "true" "try" "typedef" "typeid" "typename"
+     "union" "unsigned" "using" "virtual" "void" "volatile" "wchar_t" "while"
+     "xor" "xor_eq")
     (c-mode
+     ;; from https://en.cppreference.com/w/c/keyword
+     "_Alignas" "_Alignof" "_Atomic" "_Bool" "_Complex" "_Generic" "_Imaginary"
+     "_Noreturn" "_Static_assert" "_Thread_local"
      "auto" "break" "case" "char" "const" "continue" "default" "do"
-     "double" "else" "enum" "extern" "float" "for" "goto" "if" "int" "long"
-     "register" "return" "short" "signed" "sizeof" "static" "struct"
-     "switch" "typedef" "union" "unsigned" "void" "volatile" "while")
+     "double" "else" "enum" "extern" "float" "for" "goto" "if" "inline"
+     "int" "long" "register" "restrict" "return" "short" "signed" "sizeof"
+     "static" "struct" "switch" "typedef" "union" "unsigned" "void" "volatile"
+     "while")
     (csharp-mode
      "abstract" "add" "alias" "as" "base" "bool" "break" "byte" "case"
      "catch" "char" "checked" "class" "const" "continue" "decimal" "default"
